import {geoPath,
        geoNaturalEarth1,
        zoom,
        event,
        classed} from 'd3';

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

export const choroplethMap = (selection, props) => {
  const {
    features,
    colorScale,
    colorValue,
    selectedColorValue} = props;
  
  const gUpdate = selection.selectAll('g').data([null]);
  const gEnter = gUpdate.enter().append('g');
  const g = gUpdate.merge(gEnter);
  
  gEnter
      .append('path')
      .attr('d',pathGenerator({type: 'Sphere'}))
      .attr('class','sea')
   .merge(gUpdate.select('.sea'))
     	.attr('opacity', selectedColorValue ? 0.1 : 1)

	const countryPaths = g.selectAll('.country')
    .data(features);
  
  countryPaths
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
      .attr('fill',d=>colorScale(colorValue(d)))
    .merge(countryPaths)
      .attr('opacity', d=>
           (!selectedColorValue || selectedColorValue === colorValue(d))
           ? 1
           : 0.2)
      .classed('highlighted',
               d => selectedColorValue === colorValue(d))
    .append('title')
        .text(d=>d.properties.name+': '+colorValue(d));

	selection.call(zoom().on('zoom',()=>{
  	g.attr('transform',event.transform)}));
}