import { select,range} from 'd3';

export const colorLegend = (selection, props) => {
  const {
    colorScale,
    circleRadius, 
    spacing, 
    textOffset,
    backgroundRectWidth,
    onClick,
    selectedColorValue} = props;
  
 const n = colorScale.domain().length
  const backgroundRect = selection.selectAll('rect')
    .data([null]);
  
  backgroundRect.enter().append('rect')
    .merge(backgroundRect)
      .attr('width',backgroundRectWidth)
      .attr('height',
            n*spacing+circleRadius*2)
      .attr('fill','white')
      .attr('x',-circleRadius*2)
      .attr('y',-circleRadius*2)
      .attr('rx',circleRadius*2)
      .attr('opacity',0.5)
  
  const groups = selection.selectAll('g')
    .data(colorScale.domain());
  
  const groupsEnter = groups.enter().append('g')
    .attr('class','tick');
  groupsEnter
  .merge(groups)
    .attr('transform', (d,i)=>
    `translate(0,${i*spacing})`)
    .on('click',(d)=>{onClick(d)})
    .attr('opacity', (d)=> 
      (d==selectedColorValue || !selectedColorValue)
      ? 1
      :0.5)
  groups.exit().remove()
  
  groupsEnter.append('circle')
    .merge(groups.select('circle'))
      .attr('r',circleRadius)
      .attr('fill',colorScale)

  
  groupsEnter.append('text')
    .merge(groups.select('text'))
      .text(d=>d)
      .attr('x',textOffset)
      .attr('dy','0.32em')

}
